==> lakalapay-sdk-1.0.0.20220307.2-20230227.111518-1-sources.jar: com/fshows/lakala/client/impl/LakalaUploadFileClientImpl.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2023 All Rights Reserved.
 */
package com.fshows.lakala.client.impl;

import cn.hutool.core.util.RandomUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fshows.lakala.client.base.ApiClientConfig;
import com.fshows.lakala.client.base.IHttpRequest;
import com.fshows.lakala.client.base.ISigner;
import com.fshows.lakala.client.base.LakalaHttpResult;
import com.fshows.lakala.client.base.LakalaUploadFileClient;
import com.fshows.lakala.client.base.SignParam;
import com.fshows.lakala.constant.LakalaConstant;
import com.fshows.lakala.exception.LakalaApiException;
import com.fshows.lakala.request.base.LakalaBaseMerchantRequest;
import com.fshows.lakala.request.common.UploadPictureRequest;
import com.fshows.lakala.response.base.LakalaBaseMerchantResponse;
import com.fshows.lakala.response.common.UploadPictureReponse;
import com.fshows.lakala.util.LogUtil;
import com.fshows.lakala.util.ReqIdUtil;
import com.fshows.lakala.util.ValidateUtil;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @author zhubo
 * @version UploadFileClientImpl.java, v 0.1 2023-02-24 14:56 zhubo
 */
@Slf4j
public class LakalaUploadFileClientImpl implements LakalaUploadFileClient {


    private static final String URL = "api/v2/mms/openApi/uploadFile";
    private static final String SUCCESS = "000000";
    private ApiClientConfig apiClientConfig;
    private IHttpRequest httpRequest;
    private ISigner signer;
    private String orgCode;

    public LakalaUploadFileClientImpl(ApiClientConfig apiClientConfig, IHttpRequest httpRequest, ISigner signer, String orgCode) {
        this.apiClientConfig = apiClientConfig;
        this.httpRequest = httpRequest;
        this.signer = signer;
        this.orgCode = orgCode;
    }

    /**
     * 上传照片
     *
     * @param request 请求
     * @return {@link UploadPictureReponse}
     */
    @Override
    public UploadPictureReponse uploadPicture(UploadPictureRequest request) throws LakalaApiException {
        // 参数校验
        if (null == request) {
            LogUtil.error(log, "uploadPicture >> 参数为空");
            throw new LakalaApiException("图片上传参数为空");
        }
        ValidateUtil.validateWithThrow(request);
        // 参数填充
        request.setVersion(LakalaConstant.MERCHANT_API_VERSION_V2);
        request.setOrderNo(ReqIdUtil.getOrderNo());
        request.setOrgCode(orgCode);

        LakalaBaseMerchantRequest baseMerchantRequest = buildRequest(request);
        String body = buildBody(baseMerchantRequest);
        String reqUrl = apiClientConfig.getApiParentURL() + URL;
        SignParam signParam = buildSignParam(baseMerchantRequest, body);
        String authorization = signer.sign(signParam, this.apiClientConfig);
        Map<String, String> headers = new HashMap<>();
        headers.put("Authorization", authorization);

        long beginTime = System.currentTimeMillis();
        try {
            LogUtil.info(log, "【lakala-sdk】请求开始 >> url={}", reqUrl, headers, beginTime);
            LakalaHttpResult result = httpRequest.post(reqUrl, authorization, signParam.getBody(), apiClientConfig);
            LogUtil.info(log, "【lakala-sdk】请求结束 >> url={}, response={}, lakalaTraceId={}, cost={}ms", reqUrl,
                    result.getBody(), result.getLakalaTraceId(), System.currentTimeMillis() - beginTime);
            if (null == result) {
                throw new LakalaApiException("lakala响应结果为空");
            }
            LakalaBaseMerchantResponse baseMerchantResponse = JSON.parseObject(result.getBody(), LakalaBaseMerchantResponse.class);
            if (null == baseMerchantResponse || !SUCCESS.equals(baseMerchantResponse.getRetCode()) || null == baseMerchantResponse.getRespData()) {
                throw new LakalaApiException("上传文件失败");
            }
            return (UploadPictureReponse) baseMerchantResponse.getRespData();
        } catch (IOException e) {
            LogUtil.error(log, "【lakala-sdk】网络请求异常 >> url={}, cost={}ms",
                    e, reqUrl, (System.currentTimeMillis() - beginTime));
            throw new LakalaApiException("请求lakala接口异常", e);
        }
    }

    private LakalaBaseMerchantRequest buildRequest(UploadPictureRequest request) {
        LakalaBaseMerchantRequest baseMerchantRequest = new LakalaBaseMerchantRequest();
        baseMerchantRequest.setTimestamp(System.currentTimeMillis());
        baseMerchantRequest.setRnd(RandomUtil.randomString(12));
        baseMerchantRequest.setVer(LakalaConstant.MERCHANT_API_VERSION_V2);
        baseMerchantRequest.setReqId(ReqIdUtil.getId());
        baseMerchantRequest.setReqData(request);
        return baseMerchantRequest;
    }

    protected String buildBody(LakalaBaseMerchantRequest request) {
        return JSONObject.toJSONString(request);
    }

    private SignParam buildSignParam(LakalaBaseMerchantRequest lakalaBaseRequest, String bodyStr) {
        SignParam signParam = new SignParam();
        signParam.setAppid(apiClientConfig.getAppId());
        signParam.setSerialNo(apiClientConfig.getSerialNo());
        signParam.setBody(bodyStr);
        signParam.setNonceStr(lakalaBaseRequest.getRnd());
        signParam.setTimeStamp(lakalaBaseRequest.getTimestamp() / 1000L);
        return signParam;
    }
}

==> lakalapay-sdk-1.0.0.20220307.2-20230227.115951-2-sources.jar: com/fshows/lakala/client/impl/LakalaUploadFileClientImpl.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2023 All Rights Reserved.
 */
package com.fshows.lakala.client.impl;

import cn.hutool.core.util.RandomUtil;
import com.alibaba.fastjson.JSONObject;
import com.fshows.lakala.client.base.ApiClientConfig;
import com.fshows.lakala.client.base.IHttpRequest;
import com.fshows.lakala.client.base.ISigner;
import com.fshows.lakala.client.base.LakalaHttpResult;
import com.fshows.lakala.client.base.LakalaUploadFileClient;
import com.fshows.lakala.client.base.SignParam;
import com.fshows.lakala.constant.LakalaConstant;
import com.fshows.lakala.exception.LakalaApiException;
import com.fshows.lakala.request.base.LakalaBaseMerchantRequest;
import com.fshows.lakala.request.common.UploadPictureRequest;
import com.fshows.lakala.response.base.LakalaBaseMerchantResponse;
import com.fshows.lakala.response.common.UploadPictureReponse;
import com.fshows.lakala.util.LogUtil;
import com.fshows.lakala.util.ReqIdUtil;
import com.fshows.lakala.util.ValidateUtil;
import lombok.extern.slf4j.Slf4j;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @author zhubo
 * @version UploadFileClientImpl.java, v 0.1 2023-02-24 14:56 zhubo
 */
@Slf4j
public class LakalaUploadFileClientImpl implements LakalaUploadFileClient {


    private static final String URL = "api/v2/mms/openApi/uploadFile";
    private static final String SUCCESS = "000000";
    private ApiClientConfig apiClientConfig;
    private IHttpRequest httpRequest;
    private ISigner signer;
    private String orgCode;

    public LakalaUploadFileClientImpl(ApiClientConfig apiClientConfig, IHttpRequest httpRequest, ISigner signer, String orgCode) {
        this.apiClientConfig = apiClientConfig;
        this.httpRequest = httpRequest;
        this.signer = signer;
        this.orgCode = orgCode;
    }

    /**
     * 上传照片
     *
     * @param request 请求
     * @return {@link UploadPictureReponse}
     */
    @Override
    public UploadPictureReponse uploadPicture(UploadPictureRequest request) throws LakalaApiException {
        // 参数校验
        if (null == request) {
            LogUtil.error(log, "uploadPicture >> 参数为空");
            throw new LakalaApiException("图片上传参数为空");
        }
        ValidateUtil.validateWithThrow(request);
        // 参数填充
        request.setVersion(LakalaConstant.MERCHANT_API_VERSION_V2);
        request.setOrderNo(ReqIdUtil.getOrderNo());
        request.setOrgCode(orgCode);

        LakalaBaseMerchantRequest baseMerchantRequest = buildRequest(request);
        String body = buildBody(baseMerchantRequest);
        String reqUrl = apiClientConfig.getApiParentURL() + URL;
        SignParam signParam = buildSignParam(baseMerchantRequest, body);
        String authorization = signer.sign(signParam, this.apiClientConfig);
        Map<String, String> headers = new HashMap<>();
        headers.put("Authorization", authorization);

        long beginTime = System.currentTimeMillis();
        try {
            LogUtil.info(log, "【lakala-sdk】请求开始 >> url={}", reqUrl, headers, beginTime);
            LakalaHttpResult result = httpRequest.post(reqUrl, authorization, signParam.getBody(), apiClientConfig);
            LogUtil.info(log, "【lakala-sdk】请求结束 >> url={}, response={}, lakalaTraceId={}, cost={}ms", reqUrl,
                    result.getBody(), result.getLakalaTraceId(), System.currentTimeMillis() - beginTime);
            if (null == result) {
                throw new LakalaApiException("lakala响应结果为空");
            }
            JSONObject jsonObject = JSONObject.parseObject(result.getBody());
            UploadPictureReponse uploadPictureReponse = jsonObject.getObject(LakalaConstant.LAKALA_RESPONSE_BIZ_KEY,
                    UploadPictureReponse.class);
            jsonObject.remove(LakalaConstant.LAKALA_RESPONSE_BIZ_KEY);
            LakalaBaseMerchantResponse baseMerchantResponse = jsonObject.toJavaObject(LakalaBaseMerchantResponse.class);
            System.out.println(baseMerchantResponse);
            if (null == baseMerchantResponse || !SUCCESS.equals(baseMerchantResponse.getRetCode())) {
                throw new LakalaApiException("拉卡拉上传文件失败");
            }
            return uploadPictureReponse;
        } catch (IOException e) {
            LogUtil.error(log, "【lakala-sdk】网络请求异常 >> url={}, cost={}ms",
                    e, reqUrl, (System.currentTimeMillis() - beginTime));
            throw new LakalaApiException("请求lakala接口异常", e);
        }
    }

    private LakalaBaseMerchantRequest buildRequest(UploadPictureRequest request) {
        LakalaBaseMerchantRequest baseMerchantRequest = new LakalaBaseMerchantRequest();
        baseMerchantRequest.setTimestamp(System.currentTimeMillis());
        baseMerchantRequest.setRnd(RandomUtil.randomString(12));
        baseMerchantRequest.setVer(LakalaConstant.MERCHANT_API_VERSION_V2);
        baseMerchantRequest.setReqId(ReqIdUtil.getId());
        baseMerchantRequest.setReqData(request);
        return baseMerchantRequest;
    }

    protected String buildBody(LakalaBaseMerchantRequest request) {
        return JSONObject.toJSONString(request);
    }

    private SignParam buildSignParam(LakalaBaseMerchantRequest lakalaBaseRequest, String bodyStr) {
        SignParam signParam = new SignParam();
        signParam.setAppid(apiClientConfig.getAppId());
        signParam.setSerialNo(apiClientConfig.getSerialNo());
        signParam.setBody(bodyStr);
        signParam.setNonceStr(lakalaBaseRequest.getRnd());
        signParam.setTimeStamp(lakalaBaseRequest.getTimestamp() / 1000L);
        return signParam;
    }
}
